==> qtjambi-xml-5.15.8-sources.jar: io/qt/xml/QXmlContentHandler.java <==
package io.qt.xml;


/**
 * <p>Interface to report the logical content of XML data</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qxmlcontenthandler.html">QXmlContentHandler</a></p>
 */
@Deprecated
public interface QXmlContentHandler extends io.qt.QtObjectInterface
{
    /**
     * <p>Implementor class for interface {@link io.qt.xml.QXmlContentHandler}</p>
     */
    @Deprecated
    public static abstract class Impl extends io.qt.QtObject
        implements io.qt.xml.QXmlContentHandler
    {
        static {
            QtJambi_LibraryUtilities.initialize();
        }
        
        @io.qt.NativeAccess
        private static final class ConcreteWrapper extends QXmlContentHandler.Impl {
            
            @io.qt.NativeAccess
            private ConcreteWrapper(QPrivateConstructor p) { super(p); }
            
            @Override
            @io.qt.QtUninvokable
            public boolean characters(java.lang.String ch){
                return characters_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), ch);
            }
            private native static boolean characters_native_cref_QString(long __this__nativeId, java.lang.String ch);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean endDocument(){
                return endDocument_native(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static boolean endDocument_native(long __this__nativeId);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean endElement(java.lang.String namespaceURI, java.lang.String localName, java.lang.String qName){
                return endElement_native_cref_QString_cref_QString_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), namespaceURI, localName, qName);
            }
            private native static boolean endElement_native_cref_QString_cref_QString_cref_QString(long __this__nativeId, java.lang.String namespaceURI, java.lang.String localName, java.lang.String qName);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean endPrefixMapping(java.lang.String prefix){
                return endPrefixMapping_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), prefix);
            }
            private native static boolean endPrefixMapping_native_cref_QString(long __this__nativeId, java.lang.String prefix);
            
            
            @Override
            @io.qt.QtUninvokable
            public java.lang.String errorString(){
                return errorString_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static java.lang.String errorString_native_constfct(long __this__nativeId);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean ignorableWhitespace(java.lang.String ch){
                return ignorableWhitespace_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), ch);
            }
            private native static boolean ignorableWhitespace_native_cref_QString(long __this__nativeId, java.lang.String ch);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean processingInstruction(java.lang.String target, java.lang.String data){
                return processingInstruction_native_cref_QString_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), target, data);
            }
            private native static boolean processingInstruction_native_cref_QString_cref_QString(long __this__nativeId, java.lang.String target, java.lang.String data);
            
            
            @Override
            @io.qt.QtUninvokable
            public void setDocumentLocator(io.qt.xml.QXmlLocator locator){
                setDocumentLocator_native_QXmlLocator_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(locator));
            }
            private native static void setDocumentLocator_native_QXmlLocator_ptr(long __this__nativeId, long locator);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean skippedEntity(java.lang.String name){
                return skippedEntity_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), name);
            }
            private native static boolean skippedEntity_native_cref_QString(long __this__nativeId, java.lang.String name);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean startDocument(){
                return startDocument_native(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static boolean startDocument_native(long __this__nativeId);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean startElement(java.lang.String namespaceURI, java.lang.String localName, java.lang.String qName, io.qt.xml.QXmlAttributes atts){
                return startElement_native_cref_QString_cref_QString_cref_QString_cref_QXmlAttributes(QtJambi_LibraryUtilities.internal.nativeId(this), namespaceURI, localName, qName, QtJambi_LibraryUtilities.internal.checkedNativeId(atts));
            }
            private native static boolean startElement_native_cref_QString_cref_QString_cref_QString_cref_QXmlAttributes(long __this__nativeId, java.lang.String namespaceURI, java.lang.String localName, java.lang.String qName, long atts);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean startPrefixMapping(java.lang.String prefix, java.lang.String uri){
                return startPrefixMapping_native_cref_QString_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), prefix, uri);
            }
            private native static boolean startPrefixMapping_native_cref_QString_cref_QString(long __this__nativeId, java.lang.String prefix, java.lang.String uri);
            
        }
        
        
        public Impl(){
            super((QPrivateConstructor)null);
            initialize_native(this);
        }
        
        private native static void initialize_native(QXmlContentHandler instance);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmlcontenthandler.html#characters">QXmlContentHandler::characters(QString)</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean characters(java.lang.String ch);
        
        private native static boolean characters_native_cref_QString(long __this__nativeId, java.lang.String ch);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmlcontenthandler.html#endDocument">QXmlContentHandler::endDocument()</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean endDocument();
        
        private native static boolean endDocument_native(long __this__nativeId);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmlcontenthandler.html#endElement">QXmlContentHandler::endElement(QString,QString,QString)</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean endElement(java.lang.String namespaceURI, java.lang.String localName, java.lang.String qName);
        
        private native static boolean endElement_native_cref_QString_cref_QString_cref_QString(long __this__nativeId, java.lang.String namespaceURI, java.lang.String localName, java.lang.String qName);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmlcontenthandler.html#endPrefixMapping">QXmlContentHandler::endPrefixMapping(QString)</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean endPrefixMapping(java.lang.String prefix);
        
        private native static boolean endPrefixMapping_native_cref_QString(long __this__nativeId, java.lang.String prefix);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmlcontenthandler.html#errorString">QXmlContentHandler::errorString()const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract java.lang.String errorString();
        
        private native static java.lang.String errorString_native_constfct(long __this__nativeId);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmlcontenthandler.html#ignorableWhitespace">QXmlContentHandler::ignorableWhitespace(QString)</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean ignorableWhitespace(java.lang.String ch);
        
        private native static boolean ignorableWhitespace_native_cref_QString(long __this__nativeId, java.lang.String ch);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmlcontenthandler.html#processingInstruction">QXmlContentHandler::processingInstruction(QString,QString)</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean processingInstruction(java.lang.String target, java.lang.String data);
        
        private native static boolean processingInstruction_native_cref_QString_cref_QString(long __this__nativeId, java.lang.String target, java.lang.String data);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmlcontenthandler.html#setDocumentLocator">QXmlContentHandler::setDocumentLocator(QXmlLocator*)</a></p>
         */
        @io.qt.QtUninvokable
        public abstract void setDocumentLocator(io.qt.xml.QXmlLocator locator);
        
        private native static void setDocumentLocator_native_QXmlLocator_ptr(long __this__nativeId, long locator);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmlcontenthandler.html#skippedEntity">QXmlContentHandler::skippedEntity(QString)</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean skippedEntity(java.lang.String name);
        
        private native static boolean skippedEntity_native_cref_QString(long __this__nativeId, java.lang.String name);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmlcontenthandler.html#startDocument">QXmlContentHandler::startDocument()</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean startDocument();
        
        private native static boolean startDocument_native(long __this__nativeId);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmlcontenthandler.html#startElement">QXmlContentHandler::startElement(QString,QString,QString,QXmlAttributes)</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean startElement(java.lang.String namespaceURI, java.lang.String localName, java.lang.String qName, io.qt.xml.QXmlAttributes atts);
        
        private native static boolean startElement_native_cref_QString_cref_QString_cref_QString_cref_QXmlAttributes(long __this__nativeId, java.lang.String namespaceURI, java.lang.String localName, java.lang.String qName, long atts);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmlcontenthandler.html#startPrefixMapping">QXmlContentHandler::startPrefixMapping(QString,QString)</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean startPrefixMapping(java.lang.String prefix, java.lang.String uri);
        
        private native static boolean startPrefixMapping_native_cref_QString_cref_QString(long __this__nativeId, java.lang.String prefix, java.lang.String uri);
        
        /**
         * Constructor for internal use only.
         * @param p expected to be <code>null</code>.
         */
        @io.qt.NativeAccess
        protected Impl(QPrivateConstructor p) { super(p); } 
        
    }

    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlcontenthandler.html#characters">QXmlContentHandler::characters(QString)</a></p>
     */
    @io.qt.QtUninvokable
    public boolean characters(java.lang.String ch);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlcontenthandler.html#endDocument">QXmlContentHandler::endDocument()</a></p>
     */
    @io.qt.QtUninvokable
    public boolean endDocument();
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlcontenthandler.html#endElement">QXmlContentHandler::endElement(QString,QString,QString)</a></p>
     */
    @io.qt.QtUninvokable
    public boolean endElement(java.lang.String namespaceURI, java.lang.String localName, java.lang.String qName);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlcontenthandler.html#endPrefixMapping">QXmlContentHandler::endPrefixMapping(QString)</a></p>
     */
    @io.qt.QtUninvokable
    public boolean endPrefixMapping(java.lang.String prefix);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlcontenthandler.html#errorString">QXmlContentHandler::errorString()const</a></p>
     */
    @io.qt.QtUninvokable
    public java.lang.String errorString();
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlcontenthandler.html#ignorableWhitespace">QXmlContentHandler::ignorableWhitespace(QString)</a></p>
     */
    @io.qt.QtUninvokable
    public boolean ignorableWhitespace(java.lang.String ch);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlcontenthandler.html#processingInstruction">QXmlContentHandler::processingInstruction(QString,QString)</a></p>
     */
    @io.qt.QtUninvokable
    public boolean processingInstruction(java.lang.String target, java.lang.String data);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlcontenthandler.html#setDocumentLocator">QXmlContentHandler::setDocumentLocator(QXmlLocator*)</a></p>
     */
    @io.qt.QtUninvokable
    public void setDocumentLocator(io.qt.xml.QXmlLocator locator);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlcontenthandler.html#skippedEntity">QXmlContentHandler::skippedEntity(QString)</a></p>
     */
    @io.qt.QtUninvokable
    public boolean skippedEntity(java.lang.String name);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlcontenthandler.html#startDocument">QXmlContentHandler::startDocument()</a></p>
     */
    @io.qt.QtUninvokable
    public boolean startDocument();
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlcontenthandler.html#startElement">QXmlContentHandler::startElement(QString,QString,QString,QXmlAttributes)</a></p>
     */
    @io.qt.QtUninvokable
    public boolean startElement(java.lang.String namespaceURI, java.lang.String localName, java.lang.String qName, io.qt.xml.QXmlAttributes atts);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlcontenthandler.html#startPrefixMapping">QXmlContentHandler::startPrefixMapping(QString,QString)</a></p>
     */
    @io.qt.QtUninvokable
    public boolean startPrefixMapping(java.lang.String prefix, java.lang.String uri);
    
}

==> qtjambi-xml-5.15.13-sources.jar: io/qt/xml/QXmlContentHandler.java <==
package io.qt.xml;


/**
 * <p>Interface to report the logical content of XML data</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qxmlcontenthandler.html">QXmlContentHandler</a></p>
 */
@Deprecated
public interface QXmlContentHandler extends io.qt.QtObjectInterface
{
    /**
     * <p>Implementor class for interface {@link io.qt.xml.QXmlContentHandler}</p>
     */
    @Deprecated
    public static abstract class Impl extends io.qt.QtObject
        implements io.qt.xml.QXmlContentHandler
    {
        static {
            QtJambi_LibraryUtilities.initialize();
        }
        
        @io.qt.NativeAccess
        private static final class ConcreteWrapper extends QXmlContentHandler.Impl {
            
            @io.qt.NativeAccess
            private ConcreteWrapper(QPrivateConstructor p) { super(p); }
            
            @Override
            @io.qt.QtUninvokable
            public boolean characters(java.lang.String ch){
                return characters_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), ch);
            }
            private native static boolean characters_native_cref_QString(long __this__nativeId, java.lang.String ch);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean endDocument(){
                return endDocument_native(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static boolean endDocument_native(long __this__nativeId);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean endElement(java.lang.String namespaceURI, java.lang.String localName, java.lang.String qName){
                return endElement_native_cref_QString_cref_QString_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), namespaceURI, localName, qName);
            }
            private native static boolean endElement_native_cref_QString_cref_QString_cref_QString(long __this__nativeId, java.lang.String namespaceURI, java.lang.String localName, java.lang.String qName);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean endPrefixMapping(java.lang.String prefix){
                return endPrefixMapping_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), prefix);
            }
            private native static boolean endPrefixMapping_native_cref_QString(long __this__nativeId, java.lang.String prefix);
            
            
            @Override
            @io.qt.QtUninvokable
            public java.lang.String errorString(){
                return errorString_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static java.lang.String errorString_native_constfct(long __this__nativeId);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean ignorableWhitespace(java.lang.String ch){
                return ignorableWhitespace_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), ch);
            }
            private native static boolean ignorableWhitespace_native_cref_QString(long __this__nativeId, java.lang.String ch);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean processingInstruction(java.lang.String target, java.lang.String data){
                return processingInstruction_native_cref_QString_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), target, data);
            }
            private native static boolean processingInstruction_native_cref_QString_cref_QString(long __this__nativeId, java.lang.String target, java.lang.String data);
            
            
            @Override
            @io.qt.QtUninvokable
            public void setDocumentLocator(io.qt.xml.QXmlLocator locator){
                setDocumentLocator_native_QXmlLocator_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(locator));
            }
            private native static void setDocumentLocator_native_QXmlLocator_ptr(long __this__nativeId, long locator);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean skippedEntity(java.lang.String name){
                return skippedEntity_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), name);
            }
            private native static boolean skippedEntity_native_cref_QString(long __this__nativeId, java.lang.String name);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean startDocument(){
                return startDocument_native(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static boolean startDocument_native(long __this__nativeId);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean startElement(java.lang.String namespaceURI, java.lang.String localName, java.lang.String qName, io.qt.xml.QXmlAttributes atts){
                return startElement_native_cref_QString_cref_QString_cref_QString_cref_QXmlAttributes(QtJambi_LibraryUtilities.internal.nativeId(this), namespaceURI, localName, qName, QtJambi_LibraryUtilities.internal.checkedNativeId(atts));
            }
            private native static boolean startElement_native_cref_QString_cref_QString_cref_QString_cref_QXmlAttributes(long __this__nativeId, java.lang.String namespaceURI, java.lang.String localName, java.lang.String qName, long atts);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean startPrefixMapping(java.lang.String prefix, java.lang.String uri){
                return startPrefixMapping_native_cref_QString_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), prefix, uri);
            }
            private native static boolean startPrefixMapping_native_cref_QString_cref_QString(long __this__nativeId, java.lang.String prefix, java.lang.String uri);
            
        }
        
        
        public Impl(){
            super((QPrivateConstructor)null);
            initialize_native(this);
        }
        
        private native static void initialize_native(QXmlContentHandler instance);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmlcontenthandler.html#characters">QXmlContentHandler::characters(QString)</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean characters(java.lang.String ch);
        
        private native static boolean characters_native_cref_QString(long __this__nativeId, java.lang.String ch);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmlcontenthandler.html#endDocument">QXmlContentHandler::endDocument()</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean endDocument();
        
        private native static boolean endDocument_native(long __this__nativeId);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmlcontenthandler.html#endElement">QXmlContentHandler::endElement(QString,QString,QString)</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean endElement(java.lang.String namespaceURI, java.lang.String localName, java.lang.String qName);
        
        private native static boolean endElement_native_cref_QString_cref_QString_cref_QString(long __this__nativeId, java.lang.String namespaceURI, java.lang.String localName, java.lang.String qName);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmlcontenthandler.html#endPrefixMapping">QXmlContentHandler::endPrefixMapping(QString)</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean endPrefixMapping(java.lang.String prefix);
        
        private native static boolean endPrefixMapping_native_cref_QString(long __this__nativeId, java.lang.String prefix);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmlcontenthandler.html#errorString">QXmlContentHandler::errorString()const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract java.lang.String errorString();
        
        private native static java.lang.String errorString_native_constfct(long __this__nativeId);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmlcontenthandler.html#ignorableWhitespace">QXmlContentHandler::ignorableWhitespace(QString)</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean ignorableWhitespace(java.lang.String ch);
        
        private native static boolean ignorableWhitespace_native_cref_QString(long __this__nativeId, java.lang.String ch);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmlcontenthandler.html#processingInstruction">QXmlContentHandler::processingInstruction(QString,QString)</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean processingInstruction(java.lang.String target, java.lang.String data);
        
        private native static boolean processingInstruction_native_cref_QString_cref_QString(long __this__nativeId, java.lang.String target, java.lang.String data);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmlcontenthandler.html#setDocumentLocator">QXmlContentHandler::setDocumentLocator(QXmlLocator*)</a></p>
         */
        @io.qt.QtUninvokable
        public abstract void setDocumentLocator(io.qt.xml.QXmlLocator locator);
        
        private native static void setDocumentLocator_native_QXmlLocator_ptr(long __this__nativeId, long locator);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmlcontenthandler.html#skippedEntity">QXmlContentHandler::skippedEntity(QString)</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean skippedEntity(java.lang.String name);
        
        private native static boolean skippedEntity_native_cref_QString(long __this__nativeId, java.lang.String name);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmlcontenthandler.html#startDocument">QXmlContentHandler::startDocument()</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean startDocument();
        
        private native static boolean startDocument_native(long __this__nativeId);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmlcontenthandler.html#startElement">QXmlContentHandler::startElement(QString,QString,QString,QXmlAttributes)</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean startElement(java.lang.String namespaceURI, java.lang.String localName, java.lang.String qName, io.qt.xml.QXmlAttributes atts);
        
        private native static boolean startElement_native_cref_QString_cref_QString_cref_QString_cref_QXmlAttributes(long __this__nativeId, java.lang.String namespaceURI, java.lang.String localName, java.lang.String qName, long atts);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qxmlcontenthandler.html#startPrefixMapping">QXmlContentHandler::startPrefixMapping(QString,QString)</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean startPrefixMapping(java.lang.String prefix, java.lang.String uri);
        
        private native static boolean startPrefixMapping_native_cref_QString_cref_QString(long __this__nativeId, java.lang.String prefix, java.lang.String uri);
        
        /**
         * Constructor for internal use only.
         * @param p expected to be <code>null</code>.
         */
        @io.qt.NativeAccess
        protected Impl(QPrivateConstructor p) { super(p); } 
        
    }

    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlcontenthandler.html#characters">QXmlContentHandler::characters(QString)</a></p>
     */
    @io.qt.QtUninvokable
    public boolean characters(java.lang.String ch);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlcontenthandler.html#endDocument">QXmlContentHandler::endDocument()</a></p>
     */
    @io.qt.QtUninvokable
    public boolean endDocument();
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlcontenthandler.html#endElement">QXmlContentHandler::endElement(QString,QString,QString)</a></p>
     */
    @io.qt.QtUninvokable
    public boolean endElement(java.lang.String namespaceURI, java.lang.String localName, java.lang.String qName);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlcontenthandler.html#endPrefixMapping">QXmlContentHandler::endPrefixMapping(QString)</a></p>
     */
    @io.qt.QtUninvokable
    public boolean endPrefixMapping(java.lang.String prefix);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlcontenthandler.html#errorString">QXmlContentHandler::errorString()const</a></p>
     */
    @io.qt.QtUninvokable
    public java.lang.String errorString();
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlcontenthandler.html#ignorableWhitespace">QXmlContentHandler::ignorableWhitespace(QString)</a></p>
     */
    @io.qt.QtUninvokable
    public boolean ignorableWhitespace(java.lang.String ch);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlcontenthandler.html#processingInstruction">QXmlContentHandler::processingInstruction(QString,QString)</a></p>
     */
    @io.qt.QtUninvokable
    public boolean processingInstruction(java.lang.String target, java.lang.String data);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlcontenthandler.html#setDocumentLocator">QXmlContentHandler::setDocumentLocator(QXmlLocator*)</a></p>
     */
    @io.qt.QtUninvokable
    public void setDocumentLocator(io.qt.xml.QXmlLocator locator);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlcontenthandler.html#skippedEntity">QXmlContentHandler::skippedEntity(QString)</a></p>
     */
    @io.qt.QtUninvokable
    public boolean skippedEntity(java.lang.String name);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlcontenthandler.html#startDocument">QXmlContentHandler::startDocument()</a></p>
     */
    @io.qt.QtUninvokable
    public boolean startDocument();
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlcontenthandler.html#startElement">QXmlContentHandler::startElement(QString,QString,QString,QXmlAttributes)</a></p>
     */
    @io.qt.QtUninvokable
    public boolean startElement(java.lang.String namespaceURI, java.lang.String localName, java.lang.String qName, io.qt.xml.QXmlAttributes atts);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qxmlcontenthandler.html#startPrefixMapping">QXmlContentHandler::startPrefixMapping(QString,QString)</a></p>
     */
    @io.qt.QtUninvokable
    public boolean startPrefixMapping(java.lang.String prefix, java.lang.String uri);
    
}
